@@ -7,11 +7,11 @@ func (h entryHeap) Len() int           { return len(h) }
 func (h entryHeap) Less(i, j int) bool { return h[i].Size < h[j].Size }
 func (h entryHeap) Swap(i, j int)      { h[i], h[j] = h[j], h[i] }
 
-func (h *entryHeap) Push(x interface{}) {
+func (h *entryHeap) Push(x any) {
 	*h = append(*h, x.(dirEntry))
 }
 
-func (h *entryHeap) Pop() interface{} {
+func (h *entryHeap) Pop() any {
 	old := *h
 	n := len(old)
 	x := old[n-1]
@@ -26,11 +26,11 @@ func (h largeFileHeap) Len() int           { return len(h) }
 func (h largeFileHeap) Less(i, j int) bool { return h[i].Size < h[j].Size }
 func (h largeFileHeap) Swap(i, j int)      { h[i], h[j] = h[j], h[i] }
 
-func (h *largeFileHeap) Push(x interface{}) {
+func (h *largeFileHeap) Push(x any) {
 	*h = append(*h, x.(fileEntry))
 }
 
-func (h *largeFileHeap) Pop() interface{} {
+func (h *largeFileHeap) Pop() any {
 	old := *h
 	n := len(old)
 	x := old[n-1]
